# Pangolier

build PromQL by Python code.

[![pypi version]][pypi]
[![Documentation Status]][Documentation]

see docs at: https://pangolier.readthedocs.io

[pypi version]: https://img.shields.io/pypi/v/pangolier
[pypi]: https://pypi.org/project/pangolier
[Documentation Status]: https://readthedocs.org/projects/pangolier/badge
[Documentation]: https://pangolier.readthedocs.io
